bayespy.inference.vmp.nodes.categorical_markov_chain.CategoricalMarkovChainMoments
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical_markov_chain

.. autoclass:: CategoricalMarkovChainMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~CategoricalMarkovChainMoments.__init__
      ~CategoricalMarkovChainMoments.add_converter
      ~CategoricalMarkovChainMoments.compute_dims_from_values
      ~CategoricalMarkovChainMoments.compute_fixed_moments
      ~CategoricalMarkovChainMoments.get_converter
   
   

   
   
   